@@ -3,10 +3,7 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-try:
-    from urllib.parse import urlencode, urlparse, urlunparse
-except ImportError:
-    from urllib import urlencode
+from urllib.parse import urlencode, urlparse, urlunparse
 
 import time
 from json import loads
@@ -100,7 +97,7 @@ def _handle_challenge_phase(login_server,
 
     request_url = 'https://' + login_server + '/v2/'
     logger.debug(add_timestamp("Sending a HTTP Get request to {}".format(request_url)))
-    challenge = requests.get(request_url, verify=(not should_disable_connection_verify()))
+    challenge = requests.get(request_url, verify=not should_disable_connection_verify())
 
     if challenge.status_code != 401 or 'WWW-Authenticate' not in challenge.headers:
         from ._errors import CONNECTIVITY_CHALLENGE_ERROR
@@ -164,7 +161,7 @@ def _get_aad_token_after_challenge(cli_ctx,
 
     logger.debug(add_timestamp("Sending a HTTP Post request to {}".format(authhost)))
     response = requests.post(authhost, urlencode(content), headers=headers,
-                             verify=(not should_disable_connection_verify()))
+                             verify=not should_disable_connection_verify())
 
     if response.status_code == 429:
         if is_diagnostics_context:
@@ -200,7 +197,7 @@ def _get_aad_token_after_challenge(cli_ctx,
 
     logger.debug(add_timestamp("Sending a HTTP Post request to {}".format(authhost)))
     response = requests.post(authhost, urlencode(content), headers=headers,
-                             verify=(not should_disable_connection_verify()))
+                             verify=not should_disable_connection_verify())
 
     if response.status_code not in [200]:
         from ._errors import CONNECTIVITY_ACCESS_TOKEN_ERROR
@@ -301,7 +298,7 @@ def _get_token_with_username_and_password(login_server,
 
     logger.debug(add_timestamp("Sending a HTTP Post request to {}".format(authhost)))
     response = requests.post(authhost, urlencode(content), headers=headers,
-                             verify=(not should_disable_connection_verify()))
+                             verify=not should_disable_connection_verify())
 
     if response.status_code != 200:
         from ._errors import CONNECTIVITY_ACCESS_TOKEN_ERROR
@@ -324,7 +321,8 @@ def _get_credentials(cmd,  # pylint: disable=too-many-statements
                      repository=None,
                      artifact_repository=None,
                      permission=None,
-                     is_login_context=False):
+                     is_login_context=False,
+                     resource_group_name=None):
     """Try to get AAD authorization tokens or admin user credentials.
     :param str registry_name: The name of container registry
     :param str tenant_suffix: The registry login server tenant suffix
@@ -342,7 +340,7 @@ def _get_credentials(cmd,  # pylint: disable=too-many-statements
     cli_ctx = cmd.cli_ctx
     resource_not_found, registry = None, None
     try:
-        registry, resource_group_name = get_registry_by_name(cli_ctx, registry_name)
+        registry, resource_group_name = get_registry_by_name(cli_ctx, registry_name, resource_group_name)
         login_server = registry.login_server
         if tenant_suffix:
             logger.warning(
@@ -364,7 +362,7 @@ def _get_credentials(cmd,  # pylint: disable=too-many-statements
     url = 'https://' + login_server + '/v2/'
     try:
         logger.debug(add_timestamp("Sending a HTTP Get request to {}".format(url)))
-        challenge = requests.get(url, verify=(not should_disable_connection_verify()))
+        challenge = requests.get(url, verify=not should_disable_connection_verify())
         if challenge.status_code == 403:
             raise CLIError("Looks like you don't have access to registry '{}'. "
                            "To see configured firewall rules, run 'az acr show --query networkRuleSet --name {}'. "
@@ -455,7 +453,8 @@ def get_login_credentials(cmd,
                           registry_name,
                           tenant_suffix=None,
                           username=None,
-                          password=None):
+                          password=None,
+                          resource_group_name=None):
     """Try to get AAD authorization tokens or admin user credentials to log into a registry.
     :param str registry_name: The name of container registry
     :param str username: The username used to log into the container registry
@@ -467,7 +466,8 @@ def get_login_credentials(cmd,
                             username,
                             password,
                             only_refresh_token=True,
-                            is_login_context=True)
+                            is_login_context=True,
+                            resource_group_name=resource_group_name)
 
 
 def get_access_credentials(cmd,
@@ -477,7 +477,8 @@ def get_access_credentials(cmd,
                            password=None,
                            repository=None,
                            artifact_repository=None,
-                           permission=None):
+                           permission=None,
+                           resource_group_name=None):
     """Try to get AAD authorization tokens or admin user credentials to access a registry.
     :param str registry_name: The name of container registry
     :param str username: The username used to log into the container registry
@@ -494,7 +495,8 @@ def get_access_credentials(cmd,
                             only_refresh_token=False,
                             repository=repository,
                             artifact_repository=artifact_repository,
-                            permission=permission)
+                            permission=permission,
+                            resource_group_name=resource_group_name)
 
 
 def log_registry_response(response):
@@ -708,7 +710,7 @@ def parse_error_message(error_message, response):
 
 class RegistryException(CLIError):
     def __init__(self, message, status_code):
-        super(RegistryException, self).__init__(message)
+        super().__init__(message)
         self.status_code = status_code
 
 
