@@ -5,12 +5,10 @@
 
 # pylint: disable=line-too-long,too-many-nested-blocks,too-many-lines,too-many-return-statements
 
-import io
 import json
 from itertools import chain
 from json import JSONDecodeError
 from urllib.parse import urlparse
-from ._snapshot_custom_client import AppConfigSnapshotClient
 from ._constants import HttpHeaders
 
 import chardet
@@ -92,7 +90,7 @@ def __read_with_appropriate_encoding(file_path, format_):
     detected_encoding = __check_file_encoding(file_path)
 
     try:
-        with io.open(file_path, 'r', encoding=default_encoding) as config_file:
+        with open(file_path, 'r', encoding=default_encoding) as config_file:
             if format_ == 'json':
                 config_data = json.load(config_file)
                 # Only accept json objects
@@ -111,7 +109,7 @@ def __read_with_appropriate_encoding(file_path, format_):
         if detected_encoding == default_encoding:
             raise
 
-        with io.open(file_path, 'r', encoding=detected_encoding) as config_file:
+        with open(file_path, 'r', encoding=detected_encoding) as config_file:
             if format_ == 'json':
                 config_data = json.load(config_file)
 
@@ -293,10 +291,8 @@ def __read_kv_from_config_store(azconfig_client,
 
     if snapshot:
         try:
-            configsetting_iterable = AppConfigSnapshotClient(
-                azconfig_client
-            ).list_snapshot_kv(
-                name=snapshot,
+            configsetting_iterable = azconfig_client.list_configuration_settings(
+                snapshot_name=snapshot,
                 fields=query_fields,
                 headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id}
             )
@@ -356,7 +352,7 @@ def __read_kv_from_config_store(azconfig_client,
     # We first check if the snapshot exists before returning an empty result.
     if snapshot and len(retrieved_kvs) == 0:
         try:
-            _ = AppConfigSnapshotClient(azconfig_client).get_snapshot(name=snapshot, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
+            _ = azconfig_client.get_snapshot(name=snapshot, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
 
         except HttpResponseError as exception:
             if exception.status_code == StatusCodes.NOT_FOUND:
