@@ -85,7 +85,7 @@ def _polish_bad_errors(ex, creating_plan):
                         detail = ("Plan with requested features is not supported in current region. \n"
                                   "If creating an App Service Plan with --zone-redundant/-z, "
                                   "please see supported regions here: "
-                                  "https://docs.microsoft.com/en-us/azure/app-service/how-to-zone-redundancy#requirements")
+                                  "https://learn.microsoft.com/en-us/azure/app-service/how-to-zone-redundancy#requirements")
         else:
             detail = json.loads(ex.error_msg.response.text())['Message']
         ex = CLIError(detail)
