@@ -17,7 +17,7 @@ from azure.cli.core.commands.parameters import (
 from azure.cli.command_modules.rdbms.validators import configuration_value_validator, validate_subnet, \
     tls_validator, public_access_validator, maintenance_window_validator, ip_address_validator, \
     retention_validator, firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities, \
-    virtual_endpoint_name_validator
+    virtual_endpoint_name_validator, node_count_validator
 from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction
 
 from .randomname.generate import generate_username
@@ -94,7 +94,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('location', arg_type=get_location_type(self.cli_ctx))
             if command_group == 'postgres':
                 c.argument('version', default='11',
-                           help='Server major version. https://docs.microsoft.com/en-us/azure/postgresql/single-server/concepts-supported-versions')
+                           help='Server major version. https://learn.microsoft.com/en-us/azure/postgresql/single-server/concepts-supported-versions')
             else:
                 c.argument('version', help='Server major version.')
 
@@ -332,6 +332,27 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             help='Enable or disable the creation of default database flexibleserverdb. Default value is Enabled.'
         )
 
+        cluster_option_arg_type = CLIArgumentType(
+            arg_type=get_enum_type(['Server', 'ElasticCluster']),
+            options_list=['--cluster-option'],
+            help='Cluster option for the server. Servers are for workloads that can fit on one node. '
+                 'Elastic clusters provides schema- and row-based sharding on a database. Default value is Server.'
+        )
+
+        create_node_count_arg_type = CLIArgumentType(
+            type=int,
+            options_list=['--node-count'],
+            help='The number of nodes for elastic cluster. Range of 1 to 10. Default is 2 nodes.',
+            validator=node_count_validator
+        )
+
+        update_node_count_arg_type = CLIArgumentType(
+            type=int,
+            options_list=['--node-count'],
+            help='The number of nodes for elastic cluster. Range of 1 to 10.',
+            validator=node_count_validator
+        )
+
         auto_grow_arg_type = CLIArgumentType(
             arg_type=get_enum_type(['Enabled', 'Disabled']),
             options_list=['--storage-auto-grow'],
@@ -412,7 +433,10 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             help='Determines the public access. Enter single or range of IP addresses to be included in the allowed list of IPs. '
                  'IP address ranges must be dash-separated and not contain any spaces. '
                  'Specifying 0.0.0.0 allows public access from any resources deployed within Azure to access your server. '
-                 'Setting it to "None" sets the server in public access mode but does not create a firewall rule. ',
+                 'Setting it to "None" sets the server in public access mode but does not create a firewall rule. '
+                 'Acceptable values are \'Disabled\', \'Enabled\', \'All\', \'None\',\'{startIP}\' and '
+                 '\'{startIP}-{destinationIP}\' where startIP and destinationIP ranges from '
+                 '0.0.0.0 to 255.255.255.255. ',
             validator=public_access_validator
         )
 
@@ -527,7 +551,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
 
         promote_mode_arg_type = CLIArgumentType(
             arg_type=get_enum_type(['standalone', 'switchover']),
-            help='Whether to promote read replica to an independent server or promite it as a primary server.'
+            help='Whether to promote read replica to an independent server or promote it as a primary server.'
         )
 
         promote_option_arg_type = CLIArgumentType(
@@ -576,6 +600,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('throughput', default=None, arg_type=throughput_arg_type)
                 c.argument('performance_tier', default=None, arg_type=performance_tier_arg_type)
                 c.argument('create_default_db', default='Enabled', arg_type=create_default_db_arg_type)
+                c.argument('create_cluster', default='Server', arg_type=cluster_option_arg_type)
+                c.argument('cluster_size', default=None, arg_type=create_node_count_arg_type)
             elif command_group == 'mysql':
                 c.argument('tier', default='Burstable', arg_type=tier_arg_type)
                 c.argument('sku_name', default='Standard_B1ms', arg_type=sku_name_arg_type)
@@ -606,6 +632,10 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('database_name', arg_type=database_name_arg_type)
             c.argument('yes', arg_type=yes_arg_type)
 
+        with self.argument_context('{} flexible-server list'.format(command_group)) as c:
+            c.argument('show_cluster', options_list=['--show-cluster'], required=False, action='store_true',
+                       help='Only show elastic clusters.')
+
         with self.argument_context('{} flexible-server delete'.format(command_group)) as c:
             c.argument('yes', arg_type=yes_arg_type)
 
@@ -713,6 +743,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('active_directory_auth', arg_type=active_directory_auth_arg_type)
                 c.argument('password_auth', arg_type=password_auth_arg_type)
                 c.argument('private_dns_zone_arguments', private_dns_zone_arguments_arg_type)
+                c.argument('cluster_size', default=None, arg_type=update_node_count_arg_type)
                 c.argument('yes', arg_type=yes_arg_type)
 
         with self.argument_context('{} flexible-server upgrade'.format(command_group)) as c:
@@ -806,6 +837,22 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('server_name', options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
                 c.argument('virtual_endpoint_name', options_list=['--name', '-n'], arg_type=virtual_endpoint_arg_type, validator=virtual_endpoint_name_validator)
 
+        with self.argument_context('{} flexible-server long-term-retention list'.format(command_group)) as c:
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+
+        with self.argument_context('{} flexible-server long-term-retention show'.format(command_group)) as c:
+            c.argument('backup_name', options_list=['--backup-name', '-b'], help='Backup name.')
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+
+        with self.argument_context('{} flexible-server long-term-retention start'.format(command_group)) as c:
+            c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new long-term-retention backup.')
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+            c.argument('sas_url', options_list=['--sas-url', '-u'], help='Container SAS URL.')
+
+        with self.argument_context('{} flexible-server long-term-retention pre-check'.format(command_group)) as c:
+            c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new long-term-retention backup.')
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+
         for scope in ['create', 'update']:
             argument_context_string = '{} flexible-server virtual-endpoint {}'.format(command_group, scope)
             with self.argument_context(argument_context_string) as c:
@@ -839,6 +886,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('storage_gb', arg_type=storage_gb_arg_type)
                 c.argument('performance_tier', default=None, arg_type=performance_tier_arg_type)
                 c.argument('yes', arg_type=yes_arg_type)
+                c.argument('tags', arg_type=tags_type)
             if command_group == 'mysql':
                 c.argument('public_access', options_list=['--public-access'], arg_type=get_enum_type(['Enabled', 'Disabled']),
                            help='Determines the public access. ')
@@ -878,7 +926,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('max_file_size', type=int, help='The file size limitation to filter files.')
 
         # backups
-        if command_group == 'mysql':
+        if command_group != 'mariadb':
             with self.argument_context('{} flexible-server backup create'.format(command_group)) as c:
                 c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new backup.')
 
@@ -888,19 +936,39 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         with self.argument_context('{} flexible-server backup list'.format(command_group)) as c:
             c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
 
+        if command_group == 'postgres':
+            with self.argument_context('{} flexible-server backup delete'.format(command_group)) as c:
+                c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new backup.')
+                c.argument('yes', arg_type=yes_arg_type)
+
         # identity
         with self.argument_context('{} flexible-server identity'.format(command_group)) as c:
             c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
 
-        with self.argument_context('{} flexible-server identity assign'.format(command_group)) as c:
-            c.argument('identities', arg_type=identities_arg_type)
-
-        with self.argument_context('{} flexible-server identity remove'.format(command_group)) as c:
-            c.argument('identities', arg_type=identities_arg_type)
+        for scope in ['assign', 'remove']:
+            with self.argument_context('{} flexible-server identity'.format(command_group)) as c:
+                c.argument('identities', arg_type=identities_arg_type)
 
         with self.argument_context('{} flexible-server identity show'.format(command_group)) as c:
             c.argument('identity', options_list=['--identity', '-n'], help='Name or ID of identity to show.', validator=validate_identity)
 
+        if command_group == 'postgres':
+            with self.argument_context('{} flexible-server identity update'.format(command_group)) as c:
+                c.argument('system_assigned', options_list=['--system-assigned'], arg_type=get_enum_type(['Enabled', 'Disabled']),
+                           help='Enable or disable system assigned identity to authenticate to cloud services without storing credentials in code. Default is `Disabled`.')
+
+        # fabric mirroring
+        if command_group == 'postgres':
+            for scope in ['start', 'stop', 'update-databases']:
+                with self.argument_context('{} flexible-server fabric-mirroring'.format(command_group)) as c:
+                    c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
+                    c.argument('yes', arg_type=yes_arg_type)
+
+            for scope in ['start', 'update-databases']:
+                with self.argument_context('{} flexible-server fabric-mirroring'.format(command_group)) as c:
+                    c.argument('database_names', options_list=['--database-names', '-d'], nargs='+',
+                               help='Space-separated list of the database names to be mirrored. Required if --mirroring is enabled.')
+
         # ad-admin
         with self.argument_context('{} flexible-server ad-admin'.format(command_group)) as c:
             c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
