@@ -22,7 +22,7 @@ short-summary: Manage Microsoft Entra applications.
 helps['ad app create'] = """
 type: command
 short-summary: Create an application.
-long-summary: For more detailed documentation, see https://docs.microsoft.com/graph/api/resources/application
+long-summary: For more detailed documentation, see https://learn.microsoft.com/graph/api/resources/application
 examples:
   - name: Create an application.
     text: |
@@ -344,7 +344,7 @@ examples:
 """
 
 # The example is from
-# https://docs.microsoft.com/en-us/azure/active-directory/develop/workload-identity-federation-create-trust-github?tabs=microsoft-graph
+# https://learn.microsoft.com/en-us/azure/active-directory/develop/workload-identity-federation-create-trust-github?tabs=microsoft-graph
 helps['ad app federated-credential create'] = """
 type: command
 short-summary: Create application federated identity credential.
@@ -528,18 +528,27 @@ long-summary: >-
     You may also use `az role assignment create` to create role assignments for this service principal later.
     See [steps to add a role assignment](https://aka.ms/azadsp-more) for more information.
 examples:
-  - name: Create without role assignment.
-    text: az ad sp create-for-rbac
-  - name: Create using a custom display name.
-    text: az ad sp create-for-rbac -n MyApp
-  - name: Create with a Contributor role assignments on specified scopes. To retrieve current subscription ID, run `az account show --query id --output tsv`.
-    text: az ad sp create-for-rbac -n MyApp --role Contributor --scopes /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1 /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup2
-  - name: Create using a self-signed certificate.
-    text: az ad sp create-for-rbac --create-cert
-  - name: Create using a self-signed certificate, and store it within KeyVault.
-    text: az ad sp create-for-rbac --keyvault MyVault --cert CertName --create-cert
-  - name: Create using existing certificate in KeyVault.
-    text: az ad sp create-for-rbac --keyvault MyVault --cert CertName
+- name: Create without role assignment.
+  text: az ad sp create-for-rbac
+- name: Create using a custom display name.
+  text: az ad sp create-for-rbac -n MyApp
+- name: Create with a Contributor role assignments on specified scopes. To retrieve current subscription ID, run `az account show --query id --output tsv`.
+  text: az ad sp create-for-rbac -n MyApp --role Contributor --scopes /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1 /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup2
+- name: Create using a self-signed certificate.
+  text: az ad sp create-for-rbac --create-cert
+- name: Create using an existing certificate string.
+  text: az ad sp create-for-rbac --cert "MIICoT..."
+- name: Create using an existing certificate file.
+  text: |-
+      az ad sp create-for-rbac --cert "@~/cert.pem"
+      `cert.pem` contains the following content
+      -----BEGIN CERTIFICATE-----  <<< this line is optional
+      MIICoT...
+      -----END CERTIFICATE-----    <<< this line is optional
+- name: Create using a self-signed certificate, and store it within Azure Key Vault.
+  text: az ad sp create-for-rbac --keyvault MyVault --cert CertName --create-cert
+- name: Create using existing certificate in Azure Key Vault.
+  text: az ad sp create-for-rbac --keyvault MyVault --cert CertName
 """
 
 helps['ad sp credential'] = """
@@ -763,17 +772,34 @@ examples:
 helps['role assignment delete'] = """
 type: command
 short-summary: Delete role assignments.
+long-summary: >-
+    This command deletes all role assignments that satisfy the provided query condition. Before running this
+    command, it is highly recommended to run `az role assignment list` first with the same arguments to see which
+    role assignments will be deleted.
 examples:
-  - name: Delete role assignments. (autogenerated)
-    text: |
-        az role assignment delete --assignee 00000000-0000-0000-0000-000000000000 --role "Storage Account Key Operator Service Role"
-    crafted: true
+  - name: Delete all role assignments with "Reader" role at the subscription scope.
+    text: az role assignment delete --role Reader --scope /subscriptions/00000000-0000-0000-0000-000000000000
+  - name: Delete all role assignments of an assignee at the subscription scope.
+    text: az role assignment delete --assignee 00000000-0000-0000-0000-000000000000 --scope /subscriptions/00000000-0000-0000-0000-000000000000
 """
 
 helps['role assignment list'] = """
 type: command
 short-summary: List role assignments.
-long-summary: By default, only assignments scoped to subscription will be displayed. To view assignments scoped by resource or group, use `--all`.
+long-summary: >-
+    By default, only assignments scoped to subscription will be displayed.
+    To view assignments scoped by resource or group, use `--all`.
+
+
+    [WARNING] Azure classic subscription administrators will be retired on August 31, 2024.
+    After August 31, 2024, all classic administrators risk losing access to the subscription.
+    Delete classic administrators who no longer need access or assign an Azure RBAC role for fine-grained access
+    control. Learn more: https://go.microsoft.com/fwlink/?linkid=2238474
+examples:
+  - name: List all role assignments with "Reader" role at the subscription scope.
+    text: az role assignment list --role Reader --scope /subscriptions/00000000-0000-0000-0000-000000000000
+  - name: List all role assignments of an assignee at the subscription scope.
+    text: az role assignment list --assignee 00000000-0000-0000-0000-000000000000 --scope /subscriptions/00000000-0000-0000-0000-000000000000
 """
 
 helps['role assignment list-changelogs'] = """
