@@ -30,6 +30,7 @@ def load_arguments(self, _):
                    help='list all entities, expect long delay if under a big organization')
 
     with self.argument_context('ad app') as c:
+        # https://learn.microsoft.com/en-us/graph/api/resources/application?view=graph-rest-1.0
         c.argument('app_id', help='application id')
         c.argument('application_object_id', options_list=('--object-id',))
         c.argument('display_name', help='the display name of the application')
@@ -40,7 +41,7 @@ def load_arguments(self, _):
                         'Also known as App ID URI, this value is set when an application is used as a resource app. '
                         'The identifierUris acts as the prefix for the scopes you\'ll reference in your API\'s code, '
                         'and it must be globally unique. You can use the default value provided, which is in the '
-                        'form api://<application-client-id>, or specify a more readable URI like '
+                        'form `api://<application-client-id>`, or specify a more readable URI like '
                         'https://contoso.com/api.')
 
         c.argument('is_fallback_public_client', arg_type=get_three_state_flag(),
@@ -55,7 +56,15 @@ def load_arguments(self, _):
                                            'PersonalMicrosoftAccount']),
                    help='Specifies the Microsoft accounts that are supported for the current application.')
 
+        # api
+        # https://learn.microsoft.com/en-us/graph/api/resources/apiapplication?view=graph-rest-1.0
+        c.argument('requested_access_token_version', arg_group='api', type=int,
+                   help='Specifies the access token version expected by this resource. This changes the version and '
+                        'format of the JWT produced independent of the endpoint or client used to request the access '
+                        'token.')
+
         # web
+        # https://learn.microsoft.com/en-us/graph/api/resources/webapplication?view=graph-rest-1.0
         c.argument('web_home_page_url', arg_group='web', help='Home page or landing page of the application.')
         c.argument('web_redirect_uris', arg_group='web', nargs='+',
                    help='Space-separated values. '
@@ -71,12 +80,14 @@ def load_arguments(self, _):
                         'implicit flow.')
 
         # publicClient
+        # https://learn.microsoft.com/en-us/graph/api/resources/publicclientapplication?view=graph-rest-1.0
         c.argument('public_client_redirect_uris', arg_group='publicClient', nargs='+',
                    help='Space-separated values. '
                         'Specifies the URLs where user tokens are sent for sign-in, or the redirect URIs '
                         'where OAuth 2.0 authorization codes and access tokens are sent.')
 
         # keyCredential
+        # https://learn.microsoft.com/en-us/graph/api/resources/keycredential?view=graph-rest-1.0
         c.argument('start_date', arg_group='keyCredential',
                    help="Date or datetime at which credentials become valid (e.g. '2017-01-01T01:00:00+00:00' or "
                         "'2017-01-01'). Default value is current time")
@@ -108,19 +119,19 @@ def load_arguments(self, _):
         c.argument('optional_claims', arg_group='JSON property', type=validate_file_or_dict,
                    help="Application developers can configure optional claims in their Microsoft Entra applications to "
                         "specify the claims that are sent to their application by the Microsoft security token "
-                        "service. For more information, see https://docs.microsoft.com/azure/active-directory/develop"
+                        "service. For more information, see https://learn.microsoft.com/azure/active-directory/develop"
                         "/active-directory-optional-claims. " + JSON_PROPERTY_HELP)
 
     with self.argument_context('ad app owner list') as c:
         c.argument('identifier', options_list=['--id'], help='identifier uri, application id, or object id of the application')
 
     with self.argument_context('ad app permission') as c:
-        # https://docs.microsoft.com/en-us/graph/api/resources/requiredresourceaccess
+        # https://learn.microsoft.com/en-us/graph/api/resources/requiredresourceaccess
         c.argument('api',
                    help='requiredResourceAccess.resourceAppId - '
                         'The unique identifier for the resource that the application requires access to. '
                         'This should be equal to the appId declared on the target resource application.')
-        # https://docs.microsoft.com/en-us/graph/api/resources/resourceaccess
+        # https://learn.microsoft.com/en-us/graph/api/resources/resourceaccess
         c.argument('api_permissions', nargs='+',
                    help='Space-separated list of {id}={type}. '
                         "{id} is resourceAccess.id - The unique identifier for one of the oauth2PermissionScopes or "
@@ -205,7 +216,7 @@ def load_arguments(self, _):
             c.argument('cert', arg_group='keyCredential', validator=validate_cert,
                        help='Certificate to use for credentials. When used with `--keyvault,`, indicates the name of the '
                             'cert to use or create. Otherwise, supply a PEM or DER formatted public certificate string. '
-                            'Use `@{path}` to load from a file. Do not include private key info.')
+                            'Use `@{path}` to load from a file. Do not include the private key.')
             c.argument('create_cert', arg_group='keyCredential', action='store_true',
                        help='Create a self-signed certificate to use for the credential. Only the current OS user has '
                             'read/write permission to this certificate. Use with `--keyvault` to create the certificate in '
@@ -326,7 +337,7 @@ def load_arguments(self, _):
         c.argument('assignment_name', name_arg_type,
                    help='A GUID for the role assignment. It must be unique and different for each role assignment. If omitted, a new GUID is generated.')
 
-    time_help = ('The {} of the query in the format of %Y-%m-%dT%H:%M:%SZ, e.g. 2000-12-31T12:59:59Z. Defaults to {}')
+    time_help = 'The {} of the query in the format of %Y-%m-%dT%H:%M:%SZ, e.g. 2000-12-31T12:59:59Z. Defaults to {}'
     with self.argument_context('role assignment list-changelogs') as c:
         c.argument('start_time', help=time_help.format('start time', '1 Hour prior to the current time'))
         c.argument('end_time', help=time_help.format('end time', 'the current time'))
@@ -355,7 +366,7 @@ def load_arguments(self, _):
                         'JSON description.')
 
     with self.argument_context('role assignment delete') as c:
-        c.argument('yes', options_list=['--yes', '-y'], action='store_true', help='Continue to delete all assignments under the subscription')
+        c.argument('yes', options_list=['--yes', '-y'], action='store_true', help='Currently no-op.')
 
     with self.argument_context('role definition') as c:
         c.argument('role_definition_id', options_list=['--name', '-n'], help='the role definition name')
