@@ -81,7 +81,7 @@ def get_resource_type_by_id(resource_id):
     '''Get source or target resource type by resource id
     '''
     target_type = None
-    all_resources = dict()
+    all_resources = {}
     all_resources.update(SOURCE_RESOURCES)
     all_resources.update(TARGET_RESOURCES)
     for _type, _id in all_resources.items():
@@ -158,7 +158,7 @@ def get_client_type(cmd, namespace):
             # use '*Version' property to decide
             if client_type is None:
                 for prop, _type in prop_type_map.items():
-                    if output.get('siteConfig', dict()).get(prop, None) is not None:
+                    if output.get('siteConfig', {}).get(prop, None) is not None:
                         client_type = _type
                         break
         except Exception:  # pylint: disable=broad-except
@@ -297,7 +297,7 @@ def opt_out_auth(namespace):
 def intelligent_experience(cmd, namespace, missing_args):
     '''Use local context and interactive inputs to get arg values
     '''
-    cmd_arg_values = dict()
+    cmd_arg_values = {}
     # use commandline source/target resource args
     for arg in missing_args:
         if getattr(namespace, arg, None) is not None:
@@ -325,7 +325,7 @@ def intelligent_experience(cmd, namespace, missing_args):
             'Auth info is not specified, use default one: --user-account')
     if cmd.cli_ctx.local_context.is_on:
         # arguments found in local context
-        context_arg_values = dict()
+        context_arg_values = {}
         for arg in missing_args:
             if arg not in cmd_arg_values:
                 if get_local_context_value(cmd, arg):
@@ -333,9 +333,9 @@ def intelligent_experience(cmd, namespace, missing_args):
 
         # apply local context arguments
         param_str = ''
-        for arg in context_arg_values:
-            option = missing_args[arg].get('options')[0]
-            value = context_arg_values[arg]
+        for k, v in context_arg_values.items():
+            option = missing_args[k].get('options')[0]
+            value = v
             param_str += '{} {} '.format(option, value)
         if param_str:
             logger.warning('Apply local context arguments: %s', param_str.strip())
@@ -422,12 +422,11 @@ def validate_target_resource_id(cmd, namespace):
     '''Validate resource id of a target resource
     '''
     if getattr(namespace, 'target_id', None):
-        if not is_valid_resource_id(namespace.target_id):
+        target = get_target_resource_name(cmd)
+        if not (target == RESOURCE.FabricSql) and not is_valid_resource_id(namespace.target_id):
             e = InvalidArgumentValueError('Resource id is invalid: {}'.format(namespace.target_id))
             telemetry.set_exception(e, 'target-id-invalid')
             raise e
-
-        target = get_target_resource_name(cmd)
         pattern = TARGET_RESOURCES.get(target)
         matched = re.match(get_resource_regex(pattern), namespace.target_id, re.IGNORECASE)
         if matched:
@@ -456,7 +455,7 @@ def get_missing_source_args(cmd, namespace):
     '''Get source resource related args
     '''
     source = get_source_resource_name(cmd)
-    missing_args = dict()
+    missing_args = {}
 
     for arg, content in SOURCE_RESOURCES_PARAMS.get(source, {}).items():
         missing_args[arg] = content
@@ -474,7 +473,7 @@ def get_missing_source_create_args(cmd, namespace):
     '''Get source resource related args in create
     '''
     source = get_source_resource_name(cmd)
-    missing_args = dict()
+    missing_args = {}
 
     args = SOURCE_RESOURCES_CREATE_PARAMS.get(source)
     if args:
@@ -489,7 +488,7 @@ def get_missing_target_args(cmd):
     '''Get target resource related args
     '''
     target = get_target_resource_name(cmd)
-    missing_args = dict()
+    missing_args = {}
 
     if target in TARGET_RESOURCES_PARAMS:
         for arg, content in TARGET_RESOURCES_PARAMS.get(target).items():
@@ -503,7 +502,7 @@ def get_missing_auth_args(cmd, namespace):
     '''
     source = get_source_resource_name(cmd)
     target = get_target_resource_name(cmd)
-    missing_args = dict()
+    missing_args = {}
 
     # check if there are auth_info related params
     auth_param_exist = False
@@ -552,7 +551,7 @@ def get_missing_auth_args(cmd, namespace):
 def get_missing_connection_name(namespace):
     '''Get connection_name arg if user didn't provide it in command line
     '''
-    missing_args = dict()
+    missing_args = {}
     if getattr(namespace, 'connection_name', None) is None:
         missing_args['connection_name'] = {
             'help': 'The connection name',
@@ -565,7 +564,7 @@ def get_missing_connection_name(namespace):
 def get_missing_client_type(namespace):
     '''Get client_type arg if user didn't provide it in command line
     '''
-    missing_args = dict()
+    missing_args = {}
     if getattr(namespace, 'client_type', None) is None:
         missing_args['client_type'] = {
             'help': 'Client type of the connection',
@@ -578,7 +577,7 @@ def get_missing_client_type(namespace):
 def validate_local_default_params(cmd, namespace):  # pylint: disable=unused-argument
     '''Get missing args of local connection command
     '''
-    missing_args = dict()
+    missing_args = {}
 
     if getattr(namespace, 'id', None):
         namespace.id = namespace.id.lower()
@@ -611,7 +610,7 @@ def apply_local_default_params(cmd, namespace, arg_values):  # pylint: disable=u
 
 
 def validate_local_list_params(cmd, namespace):  # pylint: disable=unused-argument
-    missing_args = dict()
+    missing_args = {}
     if getattr(namespace, 'resource_group', None) is None:
         missing_args.update(LOCAL_CONNECTION_PARAMS.get("resource_group"))
     return missing_args
@@ -620,7 +619,7 @@ def validate_local_list_params(cmd, namespace):  # pylint: disable=unused-argume
 def validate_list_params(cmd, namespace):
     '''Get missing args of list command
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_source_resource_id(cmd, namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     return missing_args
@@ -629,7 +628,7 @@ def validate_list_params(cmd, namespace):
 def validate_create_params(cmd, namespace):
     '''Get missing args of create command
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_source_resource_id(cmd, namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     missing_args.update(get_missing_source_create_args(cmd, namespace))
@@ -643,7 +642,7 @@ def validate_create_params(cmd, namespace):
 def validate_local_create_params(cmd, namespace):
     '''Get missing args of create command
     '''
-    missing_args = dict()
+    missing_args = {}
 
     if not validate_target_resource_id(cmd, namespace):
         missing_args.update(get_missing_target_args(cmd))
@@ -654,7 +653,7 @@ def validate_local_create_params(cmd, namespace):
 def validate_addon_params(cmd, namespace):
     '''Get missing args of add command with '--new'
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_source_resource_id(cmd, namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     missing_args.update(get_missing_auth_args(cmd, namespace))
@@ -664,7 +663,7 @@ def validate_addon_params(cmd, namespace):
 def validate_update_params(cmd, namespace):
     '''Get missing args of update command
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_connection_id(namespace) and not validate_source_resource_id(cmd, namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     # missing_args.update(get_missing_auth_args(cmd, namespace))
@@ -675,7 +674,7 @@ def validate_update_params(cmd, namespace):
 def validate_local_update_params(cmd, namespace):  # pylint: disable=unused-argument
     '''Get missing args of update command
     '''
-    missing_args = dict()
+    missing_args = {}
     # missing_args.update(get_missing_auth_args(cmd, namespace))
     return missing_args
 
@@ -683,7 +682,7 @@ def validate_local_update_params(cmd, namespace):  # pylint: disable=unused-argu
 def validate_default_params(cmd, namespace):
     '''Get missing args of commands except for list, create
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_connection_id(namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     missing_args.update(get_missing_connection_name(namespace))
@@ -946,14 +945,20 @@ def validate_kafka_params(cmd, namespace):
 def validate_service_state(linker_parameters):
     '''Validate whether user provided params are applicable to service state
     '''
-    target_type = None
-    target_id = linker_parameters.get('target_service', dict()).get('id')
+    target_type = linker_parameters.get('target_service', {}).get('type')
+
+    # AzureResource and other types (e.g., FabricResource, SelfHostedResource)
+    if target_type == "AzureResource":
+        target_id = linker_parameters.get('target_service', {}).get('id')
+    else:
+        target_id = linker_parameters.get('target_service', {}).get('endpoint')
+
     for target, resource_id in TARGET_RESOURCES.items():
         matched = re.match(get_resource_regex(resource_id), target_id, re.IGNORECASE)
         if matched:
             target_type = target
 
-    if target_type == RESOURCE.AppConfig and linker_parameters.get('auth_info', dict()).get('auth_type') == 'secret':
+    if target_type == RESOURCE.AppConfig and linker_parameters.get('auth_info', {}).get('auth_type') == 'secret':
         segments = parse_resource_id(target_id)
         rg = segments.get('resource_group')
         name = segments.get('name')
