@@ -15,11 +15,11 @@ class StorageCommandsLoader(AzCommandsLoader):
     def __init__(self, cli_ctx=None):
         from azure.cli.core.commands import CliCommandType
         storage_custom = CliCommandType(operations_tmpl='azure.cli.command_modules.storage.custom#{}')
-        super(StorageCommandsLoader, self).__init__(cli_ctx=cli_ctx,
-                                                    resource_type=ResourceType.DATA_STORAGE,
-                                                    custom_command_type=storage_custom,
-                                                    command_group_cls=StorageCommandGroup,
-                                                    argument_context_cls=StorageArgumentContext)
+        super().__init__(cli_ctx=cli_ctx,
+                         resource_type=ResourceType.DATA_STORAGE,
+                         custom_command_type=storage_custom,
+                         command_group_cls=StorageCommandGroup,
+                         argument_context_cls=StorageArgumentContext)
 
     def load_command_table(self, args):
         from azure.cli.command_modules.storage.commands import load_command_table
@@ -47,20 +47,20 @@ class AzureStackStorageCommandsLoader(AzCommandsLoader):
         from azure.cli.core.commands import CliCommandType
 
         storage_custom = CliCommandType(operations_tmpl='azure.cli.command_modules.storage.custom#{}')
-        super(AzureStackStorageCommandsLoader, self).__init__(cli_ctx=cli_ctx,
-                                                              resource_type=ResourceType.DATA_STORAGE,
-                                                              custom_command_type=storage_custom,
-                                                              command_group_cls=AzureStackStorageCommandGroup,
-                                                              argument_context_cls=StorageArgumentContext)
+        super().__init__(cli_ctx=cli_ctx,
+                         resource_type=ResourceType.DATA_STORAGE,
+                         custom_command_type=storage_custom,
+                         command_group_cls=AzureStackStorageCommandGroup,
+                         argument_context_cls=StorageArgumentContext)
 
     def load_command_table(self, args):
-        super(AzureStackStorageCommandsLoader, self).load_command_table(args)
+        super().load_command_table(args)
         from azure.cli.command_modules.storage.commands_azure_stack import load_command_table
         load_command_table(self, args)
         return self.command_table
 
     def load_arguments(self, command):
-        super(AzureStackStorageCommandsLoader, self).load_arguments(command)
+        super().load_arguments(command)
         from azure.cli.command_modules.storage._params_azure_stack import load_arguments
         load_arguments(self, command)
 
