@@ -3,12 +3,10 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-
 import os
 import platform
 import subprocess
 import datetime
-import sys
 import zipfile
 import stat
 from urllib.parse import urlparse
@@ -76,7 +74,7 @@ class AzCopy:
             _urlretrieve(file_url, install_location)
             os.chmod(install_location,
                      os.stat(install_location).st_mode | stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH)
-        except IOError as err:
+        except OSError as err:
             raise CLIError('Connection error while attempting to download azcopy {}. You could also install the '
                            'specified azcopy version to {} manually. ({})'.format(AZCOPY_VERSION, install_dir, err))
 
@@ -94,9 +92,9 @@ class AzCopy:
     def run_command(self, args):
         args = [self.executable] + args
         args_hides = args.copy()
-        for i in range(len(args_hides)):
-            if args_hides[i].find('sig') > 0:
-                args_hides[i] = args_hides[i][0:args_hides[i].index('sig') + 4]
+        for i, v in enumerate(args_hides):
+            if v.find('sig') > 0:
+                args_hides[i] = v[0:v.index('sig') + 4]
         logger.warning("Azcopy command: %s", args_hides)
         env_kwargs = {}
         if self.creds and self.creds.tenant_id:
@@ -189,22 +187,18 @@ def _unserialize_non_msi_token_payload(token_info):
 
 
 def _generate_sas_token(cmd, account_name, account_key, service, resource_types='sco', permissions='rwdlacup'):
-    from .._client_factory import cloud_storage_account_service_factory
-    from .._validators import resource_type_type, services_type
-
     kwargs = {
         'account_name': account_name,
-        'account_key': account_key
+        'account_key': account_key,
+        'resource_types': resource_types,
+        'permission': permissions
     }
-    cloud_storage_client = cloud_storage_account_service_factory(cmd.cli_ctx, kwargs)
-    t_account_permissions = cmd.loader.get_sdk('common.models#AccountPermissions')
-
-    return cloud_storage_client.generate_shared_access_signature(
-        services_type(cmd.loader)(service[0]),
-        resource_type_type(cmd.loader)(resource_types),
-        t_account_permissions(_str=permissions),
-        datetime.datetime.utcnow() + datetime.timedelta(days=1)
-    )
+    from ..util import create_short_lived_blob_service_sas_track2, create_short_lived_file_service_sas_track2
+    if service == 'blob':
+        sas_token = create_short_lived_blob_service_sas_track2(cmd, **kwargs)
+    elif service == 'file':
+        sas_token = create_short_lived_file_service_sas_track2(cmd, **kwargs)
+    return sas_token
 
 
 def _get_default_install_location():
@@ -218,7 +212,7 @@ def _get_default_install_location():
     else:
         raise CLIError('The {} platform is not currently supported. If you want to know which platforms are supported, '
                        'please refer to the document for supported platforms: '
-                       'https://docs.microsoft.com/en-us/azure/storage/common/storage-use-azcopy-v10#download-azcopy'
+                       'https://learn.microsoft.com/en-us/azure/storage/common/storage-use-azcopy-v10#download-azcopy'
                        .format(system))
     return install_location
 
@@ -228,12 +222,7 @@ def _urlretrieve(url, install_location):
     req = urlopen(url)
     compressedFile = io.BytesIO(req.read())
     if url.endswith('zip'):
-        if sys.version_info.major >= 3:
-            zip_file = zipfile.ZipFile(compressedFile)
-        else:
-            # If Python version is 2.X, use StringIO instead.
-            import StringIO  # pylint: disable=import-error
-            zip_file = zipfile.ZipFile(StringIO.StringIO(req.read()))
+        zip_file = zipfile.ZipFile(compressedFile)
         for fileName in zip_file.namelist():
             if fileName.endswith('azcopy') or fileName.endswith('azcopy.exe'):
                 with open(install_location, 'wb') as f:
